@@ -18,10 +18,10 @@ ggfreqScatter <- function(x, y, by=NULL, bins=50, g=10, cuts=NULL,
 
   nx <- is.numeric(x); ny <- is.numeric(y)
   xbreaks <- if(nx) xbreaks; ybreaks <- if(ny) ybreaks
-  bins <- rep(bins, length=2)
+  bins <- rep(bins, length.out=2)
 
   bypres <- length(by) > 0
-  if(! bypres) by <- rep(0, length(x))
+  if(! bypres) by <- rep(0, times=length(x))
   
   i <-  ! (is.na(x) | is.na(y))
   x <- xtrans(x[i]); y <- ytrans(y[i])
